-------------------------------------------------------------------
-- Wrapper functions for easy usage of CS2D commands in Lua      --
-- 25.03.2011 - www.UnrealSoftware.de                            --
-------------------------------------------------------------------

-------------------------------------------------------------------
-- These functions make it easier to use CS2D commands in Lua    --
-- They call the parse functions with the fitting parameters     --
--                                                               --
-- Example without wrapper function:                             --
-- parse('spawnplayer '..id..' '..x..' ' ..y)                    --
--                                                               --
-- Example with wrapper function:                                --
-- spawnplayer(id,x,y)                                           --
--                                                               --
-- Both examples do exactly the same but using the wrapper       --
-- function is much easier and not as error-prone as using parse.--
-- Therefore it is recommended to use the wrapper functions.     --
--                                                               --
-- Use the following line to include the wrapper in your script: --
-- if wrapper~=true then dofile('sys/lua/wrapper.lua') end       --
-------------------------------------------------------------------

-- Set Wrapper state to LOADED/TRUE!
wrapper = true
dofile('sys/lua/colors.lua')
dofile('sys/lua/environment.lua')

-- Adds a bot to the team with less players.
function bot_add()
	parse('bot_add')
end

-- Adds a counter-terrorist bot.
function bot_add_ct()
	parse('bot_add_ct')
end

-- Adds a terrorist bot.
function bot_add_t()
	parse('bot_add_t')
end

-- Automatically fill the server with bots.
-- @param fill (0/1): automatically keep server filled with bots (1) or not (0)
function bot_autofill(fill)
	parse('bot_autofill '..fill)
end

-- Select how many bots will join the server after starting it.
-- @param count (0-32): number of bots which will join the server after starting
function bot_count(count)
	parse('bot_count '..count)
end

-- This setting allows you to freeze/unfreeze bots.
-- @param freeze (0/1): freeze bots (1) or not (0)
function bot_freeze(freeze)
	parse('bot_freeze '..freeze)
end

-- Select which teams bots will join.
-- @param team (0-2): 0 both, 1 T, 2 CT
function bot_jointeam(team)
	parse('bot_jointeam '..team)
end

-- This setting affects auto filling (bot_autofill).
-- The server will try to keep 1-2 free slots to allow players to join if it is enabled.
-- It will automatically kick bots to achieve this.
-- @param slots (0/1): automatically keep 1-2 slots free (1) or not (0)
function bot_keepfreeslots(slots)
	parse('bot_keepfreeslots '..slots)
end

-- Kill all bots.
function bot_kill()
	parse('bot_kill')
end

-- Sets a prefix for all bot names.
-- @param prefix (text): a prefix for botnames
function bot_prefix(prefix)
	parse('bot_prefix '..prefix)
end

-- Remove a random bot.
function bot_remove()
	parse('bot_remove')
end

-- Remove all bots on the server.
function bot_remove_all()
	parse('bot_remove_all')
end

-- Remove a counter-terrorist bot.
function bot_remove_ct()
	parse('bot_remove_ct')
end

-- Remove a terrorist bot.
function bot_remove_t()
	parse('bot_remove_t')
end

-- Sets the skill level of all bots. This mainly affects reaction times and aiming speed.
-- @param skill (0-4): skill of bots from low (0) to high (4)
function bot_skill(skill)
	parse('bot_skill '..skill)
end

-- @param weapons (0-7): weapons which bots can use
-- 	0 - all weapons (default)
-- 	1 - melee only
-- 	2 - pistols only
-- 	3 - shotguns only
-- 	4 - smgs only
-- 	5 - riles only
-- 	6 - sniper rifles only
-- 	7 - mgs only
function bot_weapons(weapons)
	parse('bot_weapons '..weapons)
end

-- Change the map on a server.
-- @param map (text): name of a map
function changelevel(map)
	parse('changelevel '..map)
end

-- Change the map on a server.
-- @param map (text): name of a map
function changemap(map)
	parse('changemap '..map)
end

-- CMSG is short for console message. It displays a console message in the console of a certain player or in the console of all players.
-- @param message (text): the message you want to send
-- @param [player] (0-32)(optional): id of a player or 0 for all players
function console_message(message, player)
	player = player or 0
	parse('cmsg '..message..' '..player)
end

-- Simulate a kill with a custom weapon.
-- This will also generate an appropriate death notice in the top right corner of the screen and give the killer an additional kill in the scoreboard.
-- @param killer (0-32): killer player id (or 0 for no killer)
-- @param victim (1-32): victim player id
-- @param weaponname (text): a name for the weapon the killer used (as text!)
-- @param [imagepath] (text)(optional): path/name of the image you want to show in deathnotice (relative to CS2D GFX folder)
-- 		Images should have a height of about 10 pixels.
function customkill(killer, victim, weaponname, imagepath)
	imagepath = ',gfx/'..imagepath or ''
	parse('customkill '..killer..' '..weaponname..imagepath..' '..victim)
end

-- Damages or repairs a certain object on the map.
-- @param id (1-X): object id
-- @param damage (-X-Y): how much damage/repair is caused
-- @param player (0-X): player (who caused the damage/repair)
function damageobject(object, damage, player)
	parse('damageobject '..object..' '..damage..' '..player)
end

-- Slap a player to death (kill him).
-- @param player (text): name or id of a player
function deathslap(player)
	parse('deathslap '..player)
end

-- Print a message to the console. Can be used for script debugging or information.
-- @param message (text): the message you want to show in the console
function echo(message)
	parse('echo '..message)
end

-- Create effects on the map. The usage of the parameters depends on the type.
-- @param effect (text): effect type
-- @param x (0-X): x position in pixels
-- @param y (0-X): y position in pixels
-- @param p1 (0-X): parameter 1 (amount in most cases)
-- @param p2 (0-X): parameter 2 (radius in most cases)
-- @param color (text): color name
-- 	'fire'
-- 		fire particles (yellow/orange/red).
-- 		p1=amount, p2=radius
-- 		r,g,b=no influence!
-- 	'smoke'
-- 		smoke particles (gray).
-- 		p1=amount, p2=radius
-- 		r,g,b=no influence!
-- 	'flare'
-- 		flare particles with certain color.
-- 		p1=amount, p2=radius
-- 		r,g,b=color
-- 	'colorsmoke'
-- 		smoke particles with certain color.
-- 		p1=amount, p2=radius
-- 		r,g,b=color
function effect(effect, x, y, p1, p2, color)
	parse('effect "'..effect..'" '..x..' '..y..' '..p1..' '..p2..' '..get_RED(color)..' '..get_GREEN(color)..' '..get_BLUE(color))
end

-- Give a weapon to a player.
-- @param player (1-32): id of a player
-- @param weapon (1-255): type id (int) or name (string) of a weapon
function equip(player, weapon)
	parse('equip '..player..' '..weapon)
end

-- Execute all scripts in a script (text) file.
-- @param file (text): path/name of the script file you want to execute (relative to CS2D folder)
function exec(file)
	parse('equip '..file)
end

-- Create an explosion somewhere at the map.
-- @param x (0-X): x position in pixels
-- @param y (0-X): y position in pixels
-- @param size (0-X): size/range in pixels
-- @param damage (0-X): explosion damage
-- @param player (0-32): source player id, 0 for no player as source
function explosion(x, y, size, damage, player)
	player = player or ''
	parse('explosion '..x..' '..y..' '..size..' '..damage..' '..player)
end

-- Flash one or all players.
-- @param player (0-32): player who will be flashed (0 for all)
-- @param intensity (0-100): flash intensity
function flashplayer(player, intensity)
	parse('flashplayer '..player..' '..intensity)
end

-- Flash all players who are close to the position + which have a direct line of sight to this position (without wall).
-- @param x (0-X): x position in pixels
-- @param y (0-X): y position in pixels
-- @param intensity (0-100): flash intensity
function flashposition(x, y, intensity)
	parse('flashposition '..x..' '..y..' '..intensity)
end

-- Print a message to the console. Can be used for script debugging or information.
-- @param color (text): color name
-- @param message (text): the message you want to show in the console
function console_log(color, message)
	print(get_color(color)..message)
end

-- Heals a player with a specific health amount.
-- @param id (1-32): id of a player
-- @param hp (1-250): health amount
function heal(id, hp)
	parse('sethealth '..id..' '..player(id, 'health') + hp)
end

-- Hits a player with a specific damage.
-- @param id (1-32): id of a player
-- @param dmg (1-250): damage of the hit.
function hit(id, dmg)
	local health = player(id, 'health')
	sethealth(id, health - dmg)
	sv_sound2(id, 'player/hit'..math.random(1, 3)..'.wav')
end

-- Hits a player in its armor.
-- @param id (1-32): id of a player
-- @param dmg (1-250): damage of the hit.
function hit_armor(id, dmg)
	local armor = player(id, 'armor')
	setarmor(id, armor - dmg)
	sv_sound2(id, 'player/kevlar'..math.random(1, 5)..'.wav')
end

-- Display or hide a text on the screen of every player.
-- @param id (0-49): internal text id
-- @param color (text): color name
-- @param text (text): the text you want to display
-- @param x (0-850): x position
-- @param y (0-480): y position
-- @param [align] (0,1,2)(optional): horizontal alignment
-- @param [valign] (0,1,2)(optional): vertical alignment
-- @param [size] (10-100)(optional): font size/height in pixels, 13 by default
function hudtxt(id, color, text, x, y, align, valign, size)
	if id > 49 then
		id = id - (id - 49)
	end
	align = align or ''
	valign = valign or ''
	size = size or ''
	parse('hudtxt '..id..' "'..get_color(color)..text..'" '..x..' '..y..' '..align..' '..valign..' '..size)
end

-- Display or hide a text on the screen of a certain player.
-- @param player (1-32): id of a player
-- @param id (0-49): internal text id
-- @param color (text): color name
-- @param text (text): the text you want to display
-- @param x (0-850): x position
-- @param y (0-480): y position
-- @param [align] (0,1,2)(optional): horizontal alignment
-- @param [valign] (0,1,2)(optional): vertical alignment
-- @param [size] (10-100)(optional): font size/height in pixels, 13 by d
function hudtxt2(player, id, color, text, x, y, align, valign, size)
	if id > 49 then
		id = id - (id - 49)
	end
	align = align or ''
	valign = valign or ''
	size = size or ''
	parse('hudtxt2 '..player..' '..id..' "'..get_color(color)..text..'" '..x..' '..y..' '..align..' '..valign..' '..size)
end

-- Lets a HUD text (specified with id) change its alpha value.
-- @param player (1-32): id of a player (or 0 for all)
-- @param id (0-49): internal text id
-- @param duration (ms): alpha fade/transition effect in milliseconds
-- @param alpha (0.0-1.0): new alpha value
function hudtxtalphafade(player, id, duration, alpha)
	parse('hudtxtalphafade '..player..' '..id..' '..duration..' '..alpha)
end

-- Lets a HUD text (specified with id) change its color. 
-- @param player (1-32): id of a player (or 0 for all)
-- @param id (0-49): internal text id
-- @param duration (ms): color fade/transition effect in milliseconds
-- @param color (text): color name
function hudtxtcolorfade(player, id, duration, color)
	parse('hudtxtcolorfade '..player..' '..id..' '..duration..' '..get_RED(color)..' '..get_GREEN(color)..' '..get_BLUE(color))
end

-- Lets a HUD text (specified with id) change its position.
-- @param player (1-32): id of a player (or 0 for all)
-- @param id (0-49): internal text id
-- @param duration (ms): alpha fade/transition effect in milliseconds
-- @param x (0-850): new x position
-- @param y (0-480): new y position
function hudtxtmove(player, id, duration, x, y)
	parse('hudtxtmove '..player..' '..id..' '..duration..' '..x..' '..y)
end

-- Show items information in console
function items()
	parse('items')
end

-- Kick a certain player from the server. You can also state a short reason for the kick if you want to.
-- @param player (text): ID or name of a player
-- @param [reason] (text)(optional): A kick reason (optional)
function kick(player, reason)
	reason = reason or ''
	parse('kick '..player..' '..reason)
end

-- Kill an object. Objects are buildings, mines, portals etc.
-- @param objectid (1-X): ID of an object
function killobject(objectid)
	parse('killobject '..objectid)
end

-- Kill a player.
-- @param player (1-32): id of a player
function killplayer(player)
	parse('killplayer '..player)
end

-- Shows a list of all bans at your server.
function listbans()
	parse('listbans')
end

-- Display list of players on server in console. The list also contains all player IDs.
function listplayers()
	parse('listplayers')
end

-- Send all console output to this address.
-- @param address (IP and Port): address of a server
function logaddress_add(address)
	parse('logaddress_add '..address)
end

-- Stop sending console output to this address.
-- @param address (IP and Port): address of a server.
function logaddress_remove(address)
	parse('logaddress_remove '..address)
end

-- Stop sending console output to any server.
function logaddress_removeall()
	parse('logaddress_removeall')
end

-- Execute a line of Lua script.
-- @param script (text): a Lua script
function lua(script)
	parse('lua '..script)
end

-- Reset the whole Lua scriptengine and remove all loaded scripts/hooks/variables.
function luareset()
	parse('luareset')
end

-- Make a player counter-terrorist.
-- @param player (text): name or id of a player
function makect(player)
	parse('makect '..player)
end

-- Make a player spectator.
-- @param player (text): name or id of a player
function makespec(player)
	parse('makespec '..player)
end

-- Make a player terrorist.
-- @param player (text): name or id of a player
function maket(player)
	parse('maket '..player)
end

-- Show map information and details in console.
function mapinfo()
	parse('mapinfo')
end

-- Change the map on a server.
-- @param map (text): name of a map
function mapchange(map)
	parse('map '..map)
end

-- Show a list of maps in console.
function maps()
	parse('maps')
end

-- AntiSpeeder is a basic protection against speedhackers. It uses a number of different techniques to detect speedhackers.
-- @param antispeeder protection (0-6): use protection against speedhackers?
-- 	0 - disabled
-- 	1 - Kick + Tempban
-- 	2 - Kick
-- 	3 - Kill
-- 	4 - Slap with 10 damage
-- 	5 - Slap with 25 damage
-- 	6 - Slap with 50 damage
function mp_antispeeder(antispeederprotection)
	parse('mp_antispeeder '..antispeederprotection)
end

-- When enabled (1) this function will automatically switch to the best game-mode when loading a map.
-- @param autogamemode (0-1): automatically switch gamemode?
function mp_autogamemode(autogamemode)
	parse('mp_autogamemode '..autogamemode)
end

-- If this is set to 1, CS2D automatically tries to keep teams even by changing the team of players.
-- @param balance (0/1): automatically try to keep teams even?
function mp_autoteambalance(balance)
	parse('mp_autoteambalance '..balance)
end

-- Set the health for a building.
-- @param building (text): name of a building
-- @param price (0-X): health
function mp_building_health(building, price)
	parse('mp_building_health '..building..' '..price)
end

--  Set the build limit for a building.
-- @param building (text): name of a building
-- @param limit (0-X): limit
function mp_building_limit(building, limit)
	parse('mp_building_limit '..building..' '..limit)
end

-- Set the price for a building.
-- @param building (text): name of a building
-- @param limit (0-X): limit
function mp_building_price(building, price)
	parse('mp_building_price '..building..' '..price)
end

-- Changes the buy menu. By default this setting is set to an empty string (""). The game will then use the standard buy menu.
-- @param items (text): a list of item ids (separated by comma) that can be bought or an empty string for the default buy menu
function mp_buymenu(items)
	parse('mp_buymenu '..items)
end

-- Control how long players are allowed to buy equipment after roundstart.
-- @param time (0-1000000): buytime in minutes (floats allowed!)
function mp_buytime(_time)
	parse('mp_buytime '.._time)
end

-- Set the C4 (bomb) timer countdown in seconds. The bomb explodes after this time.
-- @param time (0-255): countdown in seconds
function mp_c4timer(_time)
	parse('mp_c4timer '.._time)
end

-- Controls how many concurrent UDP connections are allowed by the server.
-- @param limit (8-4096): How many connections are accepted max.? (default 64)
function mp_connectionlimit(limit)
	parse('mp_connectionlimit '..limit)
end

-- Explosions do not cause any damage through walls if this setting is set to 1.
-- Set it to 0 if you want explosions to cause damage through all walls.
-- @param curtailed (0/1): are explosions curtailed by walls?
function mp_curtailedexplosions(curtailed)
	parse('mp_curtailedexplosions '..curtailed)
end

-- The damage of weapons is multiplied with this factor. Change it to make players die faster or slower.
-- @param factor (0-1000): damage factor
function mp_damagefactor(factor)
	parse('mp_damagefactor '..factor)
end

-- Control what a player drops when he dies or leaves the game.
-- @param drop (0-4): 0 everything, 1 Prim+Sec+Defuse+NV, 2 Prim+Sec+Defuse, 3 Prim+Sec, 4 Nothing
function mp_deathdrop(drop)
	parse('mp_deathdrop '..drop)
end

-- Select how much health you get each second while standing close to a dispenser.
-- @param health (0-100): health points you get each seoncds
function mp_dispenser_health(health)
	parse('mp_dispenser_health '..health)
end

-- Select how much money you get each second while standing close to a dispenser.
-- @param money (0-16000): money in $ you get each second
function mp_dispenser_money(money)
	parse('mp_dispenser_money '..money)
end

-- Select how much money a player gets when respawning.
-- For game modes like deathmacht or construction.
-- @param money (0-16000): money in $ each respawn
function mp_dmspawnmoney(money)
	parse('mp_dmspawnmoney '..money)
end

-- Select if the player is allowed to drop grenades (without activating them) or not.
-- @param drop (0/1): allow the player to drop grenades
function mp_dropgrenades(drop)
	parse('mp_dropgrenades '..drop)
end

-- 
-- @param 
function mp_floodprot(floodprotection)
	parse('mp_floodprot '..floodprotection)
end

-- Enable or disable flashlights on the server.
-- @param flashlights (0/1): disallow (0) or allow (1) clients to use flashlights
function mp_flashlight(_time)
	parse('mp_flashlight '.._time)
end

-- Enable or disable the flood protection.
-- @param protection (0/1): flood protection enabled?
function mp_floodprot(protection)
	parse('mp_floodprot '..protection)
end

-- Controls how long IPs of people who try to attack the server with UDP message flooding will be ignored.
-- @param time (10-86400): how long will IPs of flood attackers be ignored (in sec, default 600)?
function mp_floodprotignoretime(_time)
	parse('mp_floodprotignoretime '.._time)
end

-- Control the freezetime (for buying weapons). Players can't move or shoot during freezetime.
-- @param time (0-30): freezetime in seconds
function mp_freezetime(_time)
	parse('mp_freezetime '.._time)
end

-- This settings controls if players are allowed to buy new grenades after throwing/dropping their old ones.
-- @param allowed (0/1): allow grenade rebuying or not
function mp_grenaderebuy(allowed)
	parse('mp_grenaderebuy '..allowed)
end

-- Kick player after X hostagekills. Set this value to 0 if you don't want to kick players for hostages automatically.
-- @param kills (0-1000000): allowed hostagekills
function mp_hostagepenalty(kills)
	parse('mp_hostagepenalty '..kills)
end

-- This server setting controls the visibility of certain texts which appear when you hover game objects in-game.
-- The parameter must be the sum of the codes for all the texts which are supposed to be visible.
-- Use 0 if you want to hide all texts or 31 to show all texts.
-- 	The codes are the following:
-- 	1 - Player names
-- 	2 - Player health
-- 	4 - Hostages
-- 	8 - Dynamic Objects (Buildings/NPCs/...)
-- 	16 - Items
-- 	The default value for this setting is
-- 	1+2+4+8+16 = 31, which means that all texts are visible
-- @param flag (0-31): display hover texts?
function mp_hovertext(flag)
	parse('mp_hovertext '..flag)
end

-- This server setting controls the visibility of certain HUD elements.
-- The parameter must be the sum of the codes for all the HUD elements which are supposed to be visible.
-- Use 0 if you want to hide all HUD elements which are controlled by this setting.
-- 	The codes are the following:
-- 	1 - Health
-- 	2 - Armor
-- 	4 - Time
-- 	8 - Ammo
-- 	16 - Money
-- 	32 - Icons (like buyzone, rescuezone etc)
-- 	64 - Kill Messages
-- 	The default value for this setting is
-- 	1+2+4+8+16+32+64 = 127, which means that all HUD elements are visible
-- 	Example:
-- 	You just want to display health (1) and ammo (8) and hide everything else:
-- 	1+8 = 9
-- @param flag (0-127): display HUD elements?
function mp_hud(flag)
	parse('mp_hud '..flag)
end

-- Server setting to control how scripted HUD elements are scaled.
-- This setting affects: hudtxt, hudtxt2, Lua HUD images and also reqcld mode 0 (mouse position).
-- 	0 - no scaling, default
-- 	1 - scale to fit screen if script is written for 850x480 resolution
-- 	2 - scale to fit screen if script is written for 640x480 resolution (use this for old scripts)
-- 	3 - no scaling but center to fit screen if script is written for 640x480 resolution (use this for old scripts)
-- @param mode (0-3): (How) is custom HUD stuff scaled?
function mp_hudscale(mode)
	parse('mp_hudscale '..mode)
end

-- Peform this action if mp_idlekick is 1 and if a player was idle too long (mp_idletime).
-- 	0 - kick player (default)
-- 	1 - switch the team of the player to spectator
-- 	2 - slap the player
-- 	3 - kill the player
-- 	4 - show a message that the player is idle
-- @param action (0-4): 0 kick, 1 make spec., 2 slap, 3 kill, 4 show message
function mp_idleaction(action)
	parse('mp_idleaction '..action)
end

-- Set this to 1 if you want to perform an action on idle players (kick by default).
-- @param idleaction (0/1): perform action on idle players?
function mp_idlekick(idleaction)
	parse('mp_idlekick '..idleaction)
end

-- Select how long players are allowed to be idle (no movement etc.).
-- @param time (10-3600): allowed idle time in seconds before the game performs an action
function mp_idletime(_time)
	parse('mp_idletime '.._time)
end

-- Make ammunition for all firearms (not grenades!) infinite (1) or finite (0).
-- It will replace the carried-ammo-display in your HUD with a infinity-symbol.
-- @param infiniteammo (0/1): is ammo infinite?
function mp_infammo(infiniteammo)
	parse('mp_infammo '..infiniteammo)
end

-- Controls how much damaged is absorbed by kevlar vests.
-- @param percent (0.0-1.0): percentage (0.0=0%, 1.0=100%) of damage which will be absorbed by kevlar
function mp_kevlar(percent)
	parse('mp_kevlar '..percent)
end

-- Select how much percent of players in the same team have to vote a player before the server kicks them.
-- @param percent (0.0-1.0): percentage (0.0=0%, 1.0=100%) of votes needed for a kick
function mp_kickpercent(percent)
	parse('mp_kickpercent '..percent)
end

-- Select if players get money for killing buildings (construction mode).
-- @param money (0/1): do players get money for killing buildings?
function mp_killbuildingmoney(money)
	parse('mp_killbuildingmoney '..money)
end

-- Select which buildings of a player will be killed (destroyed) when the player leaves the game.
-- 	0: Kill all buildings when their builder leaves
-- 	1: Kill all buildings except for walls
-- 	2: Kill dispenser, turrets and supplies only, keep all other buildings
-- 	3: Keep all buildings, kill nothing
-- @param kill (0-3): 0 kill all, 1 don't kill walls, 2 kill disp.+turret+supply, 3 kill nothing
function mp_killbuildings(kill)
	parse('mp_killbuildings '..kill)
end

-- If this is set to 1 the server sends an information to every player who has been killed.
-- It tells him who killed him and how much health and armor this player has left.
-- @param info (0/1): show kill info?
function mp_killinfo(info)
	parse('mp_killinfo '..info)
end

-- Select if players are able to kill buildings of their teammates and if they get a penalty for this or not.
-- @param mode (0-2): 0 unkillable, 1 killable, 2 killable+penalty
function mp_killteambuildings(mode)
	parse('mp_killteambuildings '..mode)
end

-- Compensate high pings of clients by using previous positions of players when checking for hits. Set this setting to 0 to completely disable lag compensation.
-- @param max compensation time (0-10): time limit in 1/10 seconds for compensation (default 2)
function mp_lagcompensation(maxcompensationtime)
	parse('mp_lagcompensation '..maxcompensationtime)
end

-- CS2D calculates the frame offset which is used for the lag compensation with the calculation.
-- frameOffset=Ceil(playerPing/mp_lagcompensationdivisor).
-- A frame commonly takes 16.6 milliseconds(60 FPS, 1000/60) so 16 is the default value for this setting.
-- @param divisor (1-100): lag compensation divisor (default 16)
function mp_lagcompensationdivisor(divisor)
	parse('mp_lagcompensationdivisor '..divisor)
end

-- You always see all console output of commands executed remotely (RCon) in the console/logs of your server when this setting is enabled (1, default).
-- @param output (0/1): Display output of remotely executed commands?
function mp_localrconoutput(output)
	parse('mp_localrconoutput '..output)
end

-- Each map can have its own Lua script (also called "map script") which is saved as maps/MAPNAME.lua.
-- @param use (0/1): use Lua map script if available or not
function mp_luamap(use)
	parse('mp_luamap '..use)
end

-- Name of the Lua script you want to load with your server. Use an empty string if you do not want to use Lua scripts.
-- @param file (text): filename of a Lua script in sys/lua (server.lua by default)
function mp_luaserver(file)
	parse('mp_luaserver '..file)
end

-- Select if players get additional score for map goals like bomb planting, defusing etc.
-- @param score (0/1): do players get score for map goals?
function mp_mapgoalscore(score)
	parse('mp_mapgoalscore '..score)
end

-- Select how much percent of all players have to vote the same map before the server changes to this map.
-- @param percent (0.0-1.0): percentage (0.0=0%, 1.0=100%) of votes needed for a mapchange
function mp_mapvoteratio(percent)
	parse('mp_mapvoteratio '..percent)
end

-- Set the maximum number of clients with the same IP which are allowed to be at the server simultaneously.
-- @param clients (1-32): maximum allowed clients with same IP (default 5)
function mp_maxclientsip(clients)
	parse('mp_maxclientsip '..clients)
end

-- Limit for maximum rcon_password failures. Each failed attempt will be saved with IP address.
-- @param max. fails (0-100): maximum fails (0=infinite fails allowed + reset fail-cache)
function mp_maxrconfails(maxfails)
	parse('mp_maxrconfails '..maxfails)
end

-- Allow or disallow NAT hole punching. This technique makes use of the U.S.G.N. to increase the accessibility of servers behind NAT routers.
-- @param allow punching (0-1): allow NAT hole punching?
function mp_natholepunching(allowpunching)
	parse('mp_natholepunching '..allowpunching)
end

-- Use this setting to automatically kick all players who have a high ping.
-- @param limit (0-10000): maximum allowed ping
function mp_pinglimit(limit)
	parse('mp_pinglimit '..limit)
end

-- Change the time (in seconds) in that players are allowed to spawn after the start of the round.
-- @param time (0-5940): time you are allowed to spawn (instantly) after roundstart (standard game mode)
function mp_postspawn(_time)
	parse('mp_postspawn '.._time)
end

-- This is a server setting which controls if players will see a radar in the top left corner of their screen (1, default) or not (0).
-- @param radar (0-1): display radar?
function mp_radar(radar)
	parse('mp_radar '..radar)
end

-- Make players spawn on random positions.
-- @param random (0/1): do players spawn at spawnpoints (0) or at random positions (1)?
function mp_randomspawn(_random)
	parse('mp_randomspawn '.._random)
end

-- Controls if the dynamic recoil system is enabled or disabled.
-- @param dynamic recoil (0/1): disabled (0) or enabled (1)
function mp_recoil(rcoil)
	parse('mp_recoil '..rcoil)
end

-- Define which U.S.G.N. or Steam users are allowed to join the server always - even if it is already full.
-- The server will then kick a player if necessary to make room for a player with reservation.
-- 	Example:
-- mp_reservations "" (no reservations)
-- mp_reservations "1,2,3" (reservations for the U.S.G.N. users 1, 2 and 3)
-- @param reservations (text): a list of U.S.G.N. or Steam ID
function mp_reservations(reservations)
	parse('mp_reservations '..reservations)
end

-- This sets a delay for respawning. You have to wait this long before you are allowed to respawn.
-- @param delay (0-255): delay in seconds
function mp_respawndelay(delay)
	parse('mp_respawndelay '..delay)
end

-- With this setting your server changes the map automatically after playing X rounds.
-- @param rounds (0-1000000): rounds needed for mapchange
function mp_roundlimit(rounds)
	parse('mp_roundlimit '..rounds)
end

-- Control how long a round lasts (in minutes).
-- @param time (1-100): time for a round in minutes (100=infinite)
function mp_roundtime(_time)
	parse('mp_roundtime '.._time)
end

-- Controls how much the force/damage of shots is weakened when they hit a player/hostage/NPC or image hitzone.
-- @param weakening (0-100): How much are shots weakened per hit (in percent)?
function mp_shotweakening(weakening)
	parse('mp_shotweakening '..weakening)
end

-- Make smoke grenades block the field of view (1) or not block it (0). This setting only matters when fog of war is enabled (sv_fow 1).
-- @param smoke blocking (0/1): smoke grenades block the field of view (1) or not (0)
function mp_smokeblock(blocking)
	parse('mp_smokeblock '..blocking)
end

-- Select how much money new players get after joining.
-- @param money (0-16000): money in $
function mp_startmoney(money)
	parse('mp_startmoney '..money)
end

-- Defines a list of items which are available in the supply building.
-- @param itemlist (text): comma separated list of items or "default"
function mp_supply_items(itemlist)
	parse('mp_supply_items '..itemlist)
end

-- Kick player after X teamkills.
-- @param kills (0-1000000): allowed teamkills
function mp_teamkillpenalty(kills)
	parse('mp_teamkillpenalty '..kills)
end

-- Time in seconds a teleporter building needs to reload after each teleport (default: 5 sec).
-- @param reload time (0-300): seconds needed to reload
function mp_teleportreload(reloadtime)
	parse('mp_teleportreload '..reloadtime)
end

-- Define how long temporary bans are active. For example when someone has been vote-kicked.
-- @param time (1-1440): ban time in minutes
function mp_tempbantime(_time)
	parse('mp_tempbantime '.._time)
end

-- With this setting your server changes the map automatically every X minutes.
-- @param time (0-10000): time in minutes a map runs (0 = infinite)
function mp_timelimit(_time)
	parse('mp_timelimit '.._time)
end

-- Select if you want to punish teamkillers by killing them on the next round or not.
-- @param kill (0/1): kill teamkillers on next round (1) or not (0)?
function mp_tkpunish(kill)
	parse('mp_tkpunish '..kill)
end

-- The server traces all player movements when mp_trace is enabled.
-- It will reset their positions when they move too fast or through walls (by using cheats/hacks).
-- @param accuracy (0-5): level of precision, 0=disabled
function mp_trace(accuracy)
	parse('mp_trace '..'accuracy')
end

-- Control the damage each turret hit inflicts.
-- @param damage (0-1000): damage of a turret hit
function mp_turretdamage(damage)
	parse('mp_turretdamage '..damage)
end

-- Select which buildings are not available for building.
-- @param buildings (text): list of buildings which are unbuildable, seperated with ","
function mp_unbuildable(buildings)
	parse('mp_unbuildable '..buildings)
end

-- Control which weapons are NOT buyable on your server.
-- @param unbuyable (text): a list of weaponnames which are unbuyable, seperated with ","
function mp_unbuyable(unbuyable)
	parse('mp_unbuyable '..unbuyable)
end

-- Select if you want to have vulnerable (1) or invulnerable (0) hostages.
-- @param vulnerable (0/1): are hostages vulnerable?
function mp_vulnerablehostages(vulnerable)
	parse('mp_vulnerablehostages '..vulnerable)
end

-- Select how long it takes before dropped weapons disappear.
-- @param time (0-60): time in seconds a weapon stays on ground
function mp_weaponfadeout(duration)
	parse('mp_weaponfadeout '..duration)
end

-- With this setting your server changes the map automatically after one team won a certain number of rounds.
-- @param wins (0-1000000): wins needed for mapchange
function mp_winlimit(wins)
	parse('mp_winlimit '..wins)
end

-- Change the damage of a weapon.
-- @param name (text): in-game name of a weapon
-- @param damage (0-100000): damage for this weapon
function mp_wpndmg(name, damage)
	parse('mp_wpndmg '..name..' '..damage)
end

-- Changes the "z1"-damage of a weapon. The "z1" damage is used for several different things:
-- 	Damage caused by weapons with scope/zoom in zoom/scope level 1
-- 	Damage caused by melee weapons with secondary attack
-- 	Damage caused by weapons in burst mode (burst means 3 shots at a time, so damage will be multiplied with up to 3! Default is mp_wpndmg * 0.65 if this is set to 0)
-- 	Damage caused by weapons in silenced mode (they cause mp_wpndmg by default / when set to 0)
-- @param name (text): in-game name of a weapon
-- @param damage (0-100000): z1 damage for this weapon
function mp_wpndmg_z1(name, damage)
	parse('mp_wpndmg_z1 '..name..' '..damage)
end

-- Change the damage of a weapon in zoom level 2.
-- @param name (text): in-game name of a weapon
-- @param damage (0-100000): zoom 2 damage for this weapon
function mp_wpndmg_z2(name, damage)
	parse('mp_wpndmg_z2 '..name..' '..damage)
end

-- The damage zombies will take when they are hit.
-- @param percentage of damage (0.0-1.0): percentage of damage which zombies take (0.0=no damage, 1.0=full damage)
function mp_zombiedmg(percentageofdamage)
	parse('mp_zombiedmg '..percentageofdamage)
end

-- Give zombies (terrorists in Zombies!-mode) a weapon or item if they kill someone? Use 0 to give them nothing.
-- @param weapon (0-255): type id of a weapon (0 for nothing)
function mp_zombiekillequip(weapon)
	parse('mp_zombiekillequip '..weapon)
end

-- Score and frags you get as zombie for killing a survivor. The default value is +3 score/frags.
-- @param kill score (1-10): score you get as zombie for killing/infecting a survivor
function mp_zombiekillscore(killscore)
	parse('mp_zombiekillscore '..killscore)
end

-- Amount of health points recovered by zombies per second. The default value is 3.
-- @param recover (0-100): Health points recovered per second (default 3)
function mp_zombierecover(recover)
	parse('mp_zombierecover '..recover)
end

-- Make zombies faster (postive value) or slower (negative value). Zombies have the regular speed by default (0).
-- @param speedmod (-100,100): Zombie speed modifier
function mp_zombiespeedmod(speedmod)
	parse('mp_zombiespeedmod '..speedmod)
end

-- Send a message to everyone on your server.
-- @param color (text): color name
-- @param message (text): the message you want to send
function msg(color, message)
	parse('msg '..get_color(color)..message)
end

-- Execute commands on a server. You have to use rcon_pw first.
-- @param commands (text): one ore more commands
function rcon(commands)
	parse('rcon '..commands)
end

-- Specifies the RCON (remote control) password of the server you are currently connected to in order to unlock remote control options.
-- @param password (text): server rcon password
function rcon_password(password)
	parse('rcon_password '..password)
end

-- Specifies the RCON (remote control) password of the server you are currently connected to in order to unlock remote control options.
-- @param password (text): server rcon password
function rcon_pw(password)
	parse('rcon_pw '..password)
end

-- Remove an item/weapon from the map.
-- @param item (0-X): id of an item on the map
function removeitem(item)
	parse('removeitem '..item)
end

-- Reroute a player to another server. The player will be removed from the current server and then he can decide if he wants to accept the forwarding.
-- 	The address can have following forms:
-- 	XXX.XXX.XXX.XXX (just an IP address, port 36963 will be used)
-- 	XXX.XXX.XXX.XXX:YYYYY (IP address with port)
-- 	www.myaddress.xyz (URL)
-- 	www.myaddress.xyz:YYYYY (URL with port)
-- @param player (1-32): id of a player
-- @param address (text): a server address
function reroute(player, address)
	parse('reroute '..player..' '..address)
end

-- Restart the round/game in X seconds.
-- @param [delay] (0-10)(optional): restart delay in seconds
function restart(delay)
	delay = delay or 0
	parse('restart '..delay)
end

-- Restart the round/game in X seconds.
-- @param [delay] (0-10)(optional): restart delay in seconds
function restartround(delay)
	delay = delay or 0
	parse('restartround '..delay)
end

-- This command changes the amount of ammunition for a weapon.
-- @param id (1-X): player id (or dropped item id)
-- @param weapon (0-255): weapon type (or 0 if dropped item id is specified as first parameter)
-- @param ammoin (0-1000): ammo in weapon (or 1000 to keep unchanged)
-- @param ammo (0-1000): spare ammo (or 1000 to keep unchanged)
function setammo(id, weapon, ammoin, ammo)
	parse('setammo '..player..' '..ammo)
end

-- Set the armor of a player.
-- 	There is regular armor (0 - 200, decreases when the player is hit).
-- 	And special armor (201-206, stays until removed via script / another armor type is assigned)
-- 	Special Armor Types:
-- 	201 - Light Armor
-- 	202 - Armor
-- 	203 - Heavy Armor
-- 	204 - Medic Armor
-- 	205 - Super Armor
-- 	206 - Stealth Suit
-- @param player (1-32): id of a player
-- @param armor (0-255): armor
function setarmor(player, armor)
	parse('setarmor '..player..' '..armor)
end

-- Set the number of deaths of a player.
-- @param player (1-32): id of a player
-- @param deaths (0-X): deaths
function setdeaths(player, deaths)
	parse('setdeaths '..player..' '..deaths)
end

-- Set the number of assists of a player.
-- @param player (1-32): id of a player
-- @param assists (0-X): assists
function setassists(player, assists)
	parse('setassists '..player..' '..assists)
end

-- Set health of a player.
-- @param player (1-32): id of a player
-- @param health (0-250): health
function sethealth(player, health)
	parse('sethealth '..player..' '..health)
end

-- Set the health and maximum health of a player.
-- @param player (1-32): id of a player
-- @param maxhealth (1-250): maximum health
function setmaxhealth(player, maxhealth)
	parse('setmaxhealth '..player..' '..maxhealth)
end

-- Set the money of a player to a certain value.
-- @param player (1-32): id of a player
-- @param money (0-16000): money in $
function setmoney(player, money)
	parse('setmoney '..player..' '..money)
end

-- player (1-32): id of a player.
-- @param player (1-32): id of a player
-- @param name (text): name for the player
-- @param [hide] (0-1)(optional): 0 (default) to show the name change in the chat area, 1 to hide it
function setname(player, name, hide)
	hide = hide or ''
	parse('setname '..player..' '..name..' '..hide)
end

-- Set a player at a certain position.
-- @param player (1-32): id of a player
-- @param x (0-X): x position (in pixels)
-- @param y (0-X): y position (in pixels)
function setpos(player, x, y)
	parse('setpos '..player..' '..x..' '..y)
end

-- Set the score (value displayed in the scoreboard) of a player.
-- @param score (0-X): score
function setscore(player, score)
	parse('setscore '..player..' '..score)
end

-- Changes the team scores of the Terrorists/zombies and the Counter-Terrorists/survivors.
-- @param tscore (0-65535): Terrorists team score
-- @param ctscore (0-65535): Counter-Terrorists team score
function setteamscores(tscore, ctscore)
	parse('setteamscores '..tscore..' '..ctscore)
end

-- Changes the specified tile on the map to the given tile frame.
-- @param x (0-X): map x position (in tiles)
-- @param y (0-X): map y position (in tiles)
-- @param tile (0-255): tile frame index
function settile(x, y, tile)
	parse('settile '..x..' '..y..' '..tile)
end

-- Set the active weapon a certain player holds in his hand.
-- @param player (1-32): id of a player
-- @param weapon (1-255): type id (int) or name (string) of a weapon
function setweapon(player, weapon)
	parse('setweapon '..player..' '..weapon)
end

-- Shake a player. The maximum power/intensity is 30. However you can use higher values for a longer shake.
-- @param player (1-32): player who will have a shaking screen
-- @param power (0-X): Shake power
function shake(player, power)
	parse('shake '..player..' '..power)
end

-- Slap a player (remove some health).
-- @param player (text): name or id of a player
function slap(player)
	parse('slap '..player)
end

-- Spawn an item at a certain position (in tiles) of the map.
-- @param item (1-255): type id (int) or name (string) of an item
-- @param x (0-X): map x position (in tiles)
-- @param y (0-X): map y position (in tiles)
-- @param [ammoin] (0-X)(optional): custom ammo in weapon value
-- @param [ammo] (0-X)(optional): custom spare ammo value
function spawnitem(item, x, y, ammoin, ammo)
	ammoin = ammoin or ''
	ammo = ammo or ''
	parse('spawnitem '..item..' '..x..' '..y..' '..ammoin..' '..ammo)
end

-- Create an NPC.
-- 	NPC types:
-- 	1 - zombie
-- 	2 - headcrab
-- 	3 - snark
-- 	4 - vortigaunt
-- 	5 - soldier
-- @param type (1-X): npc type
-- @param x (0-X): x pos in tiles
-- @param y (0-X): y pos in tilesx (0-X): x pos in tiles
-- @param rot (0-360): rotation
function spawnnpc(_type, x, y, rot)
	parse('spawnnpc '.._type..' '..x..' '..y..' '..rot)
end

-- Create an object.
-- @param type (1-X): object type
-- @param x (0-X): x pos in pixels/tiles (depending on type)
-- @param y (0-X): y pos in pixels/tiles (depending on type)
-- @param rot (0-360): rotation
-- @param mode (0-X): object mode
-- @param team (0-X): object team (0=neutral, 1=T, 2=CT)
-- @param player (0-X): player (creator or for NPCs the type)
function spawnobject(_type, x, y, rot, mode, team, player)
	parse('spawnobject '.._type..' '..x..' '..y..' '..rot..' '..mode..' '..team..' '..player)
end

-- Spawn a player at a certain position.
-- @param player (1-32): id of a player
-- @param x (0-X): x position (in pixels)
-- @param y (0-X): y position (in pixels)
function spawnplayer(player, x, y)
	parse('spawnplayer '..player..' '..x..' '..y)
end

-- Spawns a projectile.
-- @param player (0-32): id of a player who spawned the projectile (0 if not by player)
-- @param type (1-X): projectile type
-- @param x (0-X): x position in pixels
-- @param y (0-X): y position in pixels
-- @param flydist (0-X): flight distance in pixels
-- @param dir (0-360): flight direction (angle in degrees)
function spawnprojectile(player, type, x, y, flydist, dir)
	parse('spawnprojectile '..player..' '..type..' '..x..' '..y..' '..flydist..' '..dir)
end

-- Modify the speed of a player.
-- The speed modifier ranges from -100 to 100. -100 means no movement, 0 is regular speed and 100 is very fast movement.
-- @param player (1-32): id of a player
-- @param speedmod (-100-100): speed modifier
function speedmod(player, speedmod)
	parse('speedmod '..player..' '..speedmod)
end

-- Remove a weapon from a player.
-- @param player (1-32): id of a player
-- @param weapon (1-255): type id (int) or name (string) of a weapon
function strip(player, weapon)
	parse('strip '..player..' '..weapon)
end

-- Control if you want the U.S.G.N. masterserver to check U.S.G.N. login IDs before a player joins (1, default) or not (0).
-- @param check (0/1): Always check U.S.G.N. login ID?
function sv_checkusgnlogin(check)
	parse('sv_checkusgnlogin '..check)
end

-- Changes the angle and the brightness of the day light time.
-- 	1: use the value defined by the map
-- 	0 - 180: night, pitch-black
-- 	180 - 210: dawn, getting brighter, shadow directing east to south-east
-- 	210 - 330: day, full brightness, shadow directing south-east to south-west
-- 	330 - 360: dusk, getting darker, shadow directing south-west to west
-- @param timeangle (-1-360): the day light time angle (-1 for map default)
function sv_daylighttime(timeangle)
	parse('sv_daylighttime '..timeangle)
end

-- Sets the "force light" server setting.
-- @param forcelight (0/1): force light?
function sv_forcelight(forcelight)
	parse('sv_forcelight '..forcelight)
end

-- Set the fog of war mode. Fog of war makes the game more realistic by hiding stuff which is out of the players view angle and behind walls.
-- 	0 - off, everything is visible
-- 	1 - hide characters only (npcs, hostages and players in fog of war will be hidden)
-- 	2 - hide characters and effects (hide characters and also all particle effects in fog of war)
-- 	3 - hide everything (everything will be hidden, including items and flying projectiles. only the map itself and buildings will be visible)
-- @param fow (0-3): Fog of war mode
function sv_fow(fow)
	parse('sv_fow '..fow)
end

-- Select if you want players to be able to hurt and even kill their teammates (1) or not (0, default).
-- @param friendlyfire (0/1): allow to hurt teammates?
function sv_friendlyfire(friendlyfire)
	parse('sv_friendlyfire '..friendlyfire)
end

-- Select the mode you want to play on your server.
-- 	0 - Standard.
-- 	1 - Deathmatch.
-- 	2 - Team Deathmatch.
-- 	3 - Construction.
-- 	4 - Zombies!
-- @param mode (0-X): a number from 0 to X for a game mode (0 = normal cs2d)
function sv_gamemode(mode)
	parse('sv_gamemode '..mode)
end

-- Select the mode you want to play on your server.
-- 	0 - Standard.
-- 	1 - Deathmatch.
-- 	2 - Team Deathmatch.
-- 	3 - Construction.
-- 	4 - Zombies!
-- @param mode (0-X): a number from 0 to X for a game mode (0 = normal cs2d)
function sv_gm(mode)
	parse('sv_gm '..mode)
end

-- Select the port you want to use for your server. 36963 is the default port and highly recommended.
-- @param port (0-65535): port, 0 = auto detect
function sv_hostport(port)
	parse('sv_hostport '..port)
end

-- Set this setting to 1 if you want to play in a LAN only.
-- @param lan (0/1): use lan mode?
function sv_lan(lan)
	parse('sv_lan '..lan)
end

-- Change the map on a server.
-- @param map (text): name of a map
function sv_map(map)
	parse('sv_map '..map)
end

-- Allow (1) or disallow (0) the server to send maps to clients/players who don't have these maps.
-- @param transfer (0/1): allow the server to send maps?
function sv_maptransfer(transfer)
	parse('sv_maptransfer '..transfer)
end

-- Set the maximum of players allowed on your server. CS2D does not allow more than 32 players.
-- @param players (1-32): player limit
function sv_maxplayers(players)
	parse('sv_maxplayers '..players)
end

-- Send a message to everyone on your server.
-- @param color (text): color name
-- @param message (text): the message you want to send
function sv_msg(color, message)
	parse('sv_msg '..get_color(color)..message)
end

-- Send a message to a certain player on your server.
-- @param player (1-32): ID of a player
-- @param color (text): color name
-- @param message (text): the message you want to send
function sv_msg2(player, color, message)
	parse('sv_msg2 '..player..' '..get_color(color)..message)
end

-- Send a message to a certain player in a certain radius from a position.
-- @param x (0-X): x pos in pixels/tiles
-- @param y (0-X): y pos in pixels/tiles
-- @param color (text): color name
-- @param message (text): the message you want to send
-- @param radius (1-X): radius from position where players will see the message.
function sv_msg3(x, y, color, message, radius)
	for _, id in pairs(player(0, 'table')) do
		if math.sqrt(math.pow(x - player(id, 'x'), 2) + math.pow(y - player(id, 'y'), 2)) < radius then
			sv_msg2(id, color, message)
		end
	end
end

-- Set the name of your server.
-- @param name (text): name for your server
function sv_name(name)
	parse('sv_name '..name)
end

-- Set a server password. Everyone who wants to join has to enter this password.
-- @param password (text): server password
function sv_password(password)
	parse('sv_password '..password)
end

-- Set an rcon (remote control) password to allow remote control. People who want to remote control your server have to enter this password.
-- Set an empty password to remove it and disallow remote control (default).
-- @param rcon password (text): password for rcon access
function sv_rcon(rconpassword)
	parse('sv_rcon '..rconpassword)
end

-- Defines which U.S.G.N. and Steam users are allowed to use RCon (remote control).
-- @param users (text): a list of U.S.G.N. and/or Steam IDs
function sv_rconusers(users)
	parse('sv_rconusers '..users)
end

-- Restart the round/game in X seconds.
-- @param delay (0-10): restart delay in seconds
function sv_restart(delay)
	parse('sv_restart '..delay)
end

-- Restart the round/game in X seconds.
-- @param delay (0-10): restart delay in seconds
function sv_restartround(delay)
	parse('sv_restartround '..delay)
end

-- Play a sound. Everyone on the server who has the soundfile will hear it.
-- @param soundfile (text): a path to a soundfile. relative to the sfx folder
function sv_sound(soundfile)
	parse('sv_sound '..soundfile)
end

-- Play a sound for a certain player. Only this player will hear it and only if he has the soundfile!
-- @param player (1-32): ID of a player
-- @param soundfile (text): a path to a soundfile. relative to the sfx folder
function sv_sound2(player, soundfile)
	parse('sv_sound2 '..player..' '..soundfile)
end

-- Play a sound for a certain player within radius. Only players will hear it and only if they have the soundfile!
-- @param x (0-X): x pos in pixels/tiles
-- @param y (0-X): y pos in pixels/tiles
-- @param soundfile (text): a path to a soundfile. relative to the sfx folder
-- @param radius (1-X): radius from position where players will listen the sound.
function sv_sound3(x, y, soundfile, radius)
	for _, id in pairs(player(0, 'table')) do
		if math.sqrt(math.pow(x - player(id, 'x'), 2) + math.pow(y - player(id, 'y'), 2)) < radius then
			sv_sound2(id, soundfile)
		end
	end
end

-- Plays a sound at a specific position. By default for all players but can be restricted to a specific player with the player parameter.
-- @param soundfile (text): a path to a soundfile. relative to the sfx folder
-- @param x (0-X): x position (in pixels)
-- @param y (0-X): y position (in pixels)
-- @param [player] (1-32)(optional): ID of a player (played for all if not set)
function sv_soundpos(soundfile, x, y, player)
	parse('sv_soundpos '..soundfile..' '..x..' '..y..' '..player)
end

-- Control what people are able to spectate (everything, own team only, nothing).
-- @param mode (0-2): spectate mode
function sv_specmode(mode)
	parse('sv_specmode '..mode)
end

-- Select if you want your server to send and receive custom sprays.
-- People on your server will only see default sprays if you disable this option.
-- @param spray transfer (0/1): allow to send sprays?
function sv_spraytransfer(spraytransfer)
	parse('sv_spraytransfer '..spraytransfer)
end

-- Stops playback of all sounds with the given file name which have been started before using sv_sound or sv_sound2.
-- @param soundfile (text): a path to a soundfile. relative to the sfx folder
-- @param player (0-32): ID of a player or 0 for all players
function sv_stopsound(soundfile, player)
	parse('sv_stopsound '..soundfile..' '..player)
end

-- Select if you want to allow U.S.G.N. users only.
-- @param usgn only (0/1): only allow U.S.G.N. users?
function sv_usgnonly(usgnonly)
	parse('sv_usgnonly '..usgnonly)
end

-- Control the upload speed (kilobytes per second) for the map- and file-transfer.
-- @param speed (1-500): upload speed in kb/s
function transfer_speed(speed)
	parse('transfer_speed '..speed)
end

-- Trigger entities.
-- 	Example:
-- 	trigger "test" (triggers all entities with the name test)
-- 	trigger "a,b,c" (triggers all entities with the names a, b and c)
-- @param trigger (text): names of entities you want to trigger
function trigger(trigger)
	parse('trigger '..trigger)
end

-- Removes a particular ban with a certain banmask.
-- 	This mask can be:
-- 	- a USGN ID (just a single number). e.g.: 1 or 123
-- 	- an IP address (also with * wildcards). e.g.: 111.222.333.444 or 111.222.333.*
-- 	- a nick name. e.g.: Player
-- @param banmask (text): USGN ID, IP or nickname
function unban(banmask)
	parse('unban '..banmask)
end

-- Removes ALL bans.
function unbanall()
	parse('unbanall')
end

-- Force a U.S.G.N. serverlist add request for the server.
function usgn_addserver()
	parse('usgn_addserver')
end

-- Show U.S.G.N. (Unreal Software Gaming Network) details.
function usgn_info()
	parse('usgn_info')
end